nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Hpcomr

Struct Hpcomr 

#[repr(transparent)]
pub struct Hpcomr(pub u32);
SNVS_HP Command Register

Tuple Fields

0: u32

Implementations

Source

impl Hpcomr

pub const fn ssm_st(&self) -> bool

SSM State Transition Transition state of the system security monitor

pub const fn set_ssm_st(&mut self, val: bool)

SSM State Transition Transition state of the system security monitor

pub const fn ssm_st_dis(&self) -> SsmStDis

SSM Secure to Trusted State Transition Disable When set, disables the SSM transition from secure to trusted state

pub const fn set_ssm_st_dis(&mut self, val: SsmStDis)

SSM Secure to Trusted State Transition Disable When set, disables the SSM transition from secure to trusted state

pub const fn ssm_sfns_dis(&self) -> SsmSfnsDis

SSM Soft Fail to Non-Secure State Transition Disable When set, it disables the SSM transition from soft fail to non-secure state

pub const fn set_ssm_sfns_dis(&mut self, val: SsmSfnsDis)

SSM Soft Fail to Non-Secure State Transition Disable When set, it disables the SSM transition from soft fail to non-secure state

pub const fn lp_swr(&self) -> LpSwr

LP Software Reset When set to 1, most registers in the SNVS_LP section are reset, but the following registers are not reset by an LP software reset: Monotonic Counter Secure Real Time Counter Time Alarm Register This bit cannot be set when the LP_SWR_DIS bit is set

pub const fn set_lp_swr(&mut self, val: LpSwr)

LP Software Reset When set to 1, most registers in the SNVS_LP section are reset, but the following registers are not reset by an LP software reset: Monotonic Counter Secure Real Time Counter Time Alarm Register This bit cannot be set when the LP_SWR_DIS bit is set

pub const fn lp_swr_dis(&self) -> LpSwrDis

LP Software Reset Disable When set, disables the LP software reset

pub const fn set_lp_swr_dis(&mut self, val: LpSwrDis)

LP Software Reset Disable When set, disables the LP software reset

pub const fn sw_sv(&self) -> bool

Software Security Violation When set, the system security monitor treats this bit as a non-fatal security violation

pub const fn set_sw_sv(&mut self, val: bool)

Software Security Violation When set, the system security monitor treats this bit as a non-fatal security violation

pub const fn sw_fsv(&self) -> bool

Software Fatal Security Violation When set, the system security monitor treats this bit as a fatal security violation

pub const fn set_sw_fsv(&mut self, val: bool)

Software Fatal Security Violation When set, the system security monitor treats this bit as a fatal security violation

pub const fn sw_lpsv(&self) -> bool

LP Software Security Violation When set, SNVS_LP treats this bit as a security violation

pub const fn set_sw_lpsv(&mut self, val: bool)

LP Software Security Violation When set, SNVS_LP treats this bit as a security violation

pub const fn prog_zmk(&self) -> ProgZmk

Program Zeroizable Master Key This bit activates ZMK hardware programming mechanism

pub const fn set_prog_zmk(&mut self, val: ProgZmk)

Program Zeroizable Master Key This bit activates ZMK hardware programming mechanism

pub const fn mks_en(&self) -> MksEn

Master Key Select Enable When not set, the one time programmable (OTP) master key is selected by default

pub const fn set_mks_en(&mut self, val: MksEn)

Master Key Select Enable When not set, the one time programmable (OTP) master key is selected by default

pub const fn hac_en(&self) -> bool

High Assurance Counter Enable This bit controls the SSM transition from the soft fail to the hard fail state

pub const fn set_hac_en(&mut self, val: bool)

High Assurance Counter Enable This bit controls the SSM transition from the soft fail to the hard fail state

pub const fn hac_load(&self) -> HacLoad

High Assurance Counter Load When set, it loads the High Assurance Counter Register with the value of the High Assurance Counter Load Register

pub const fn set_hac_load(&mut self, val: HacLoad)

High Assurance Counter Load When set, it loads the High Assurance Counter Register with the value of the High Assurance Counter Load Register

pub const fn hac_clear(&self) -> HacClear

High Assurance Counter Clear When set, it clears the High Assurance Counter Register

pub const fn set_hac_clear(&mut self, val: HacClear)

High Assurance Counter Clear When set, it clears the High Assurance Counter Register

pub const fn hac_stop(&self) -> bool

High Assurance Counter Stop This bit can be set only when SSM is in soft fail state

pub const fn set_hac_stop(&mut self, val: bool)

High Assurance Counter Stop This bit can be set only when SSM is in soft fail state

pub const fn npswa_en(&self) -> bool

Non-Privileged Software Access Enable When set, allows non-privileged software to access all SNVS registers, including those that are privileged software read/write access only

pub const fn set_npswa_en(&mut self, val: bool)

Non-Privileged Software Access Enable When set, allows non-privileged software to access all SNVS registers, including those that are privileged software read/write access only