nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Hpcr

Struct Hpcr 

#[repr(transparent)]
pub struct Hpcr(pub u32);
SNVS_HP Control Register

Tuple Fields

0: u32

Implementations

Source

impl Hpcr

pub const fn rtc_en(&self) -> bool

HP Real Time Counter Enable

pub const fn set_rtc_en(&mut self, val: bool)

HP Real Time Counter Enable

pub const fn hpta_en(&self) -> bool

HP Time Alarm Enable When set, the time alarm interrupt is generated if the value in the HP Time Alarm Registers is equal to the value of the HP Real Time Counter

pub const fn set_hpta_en(&mut self, val: bool)

HP Time Alarm Enable When set, the time alarm interrupt is generated if the value in the HP Time Alarm Registers is equal to the value of the HP Real Time Counter

pub const fn dis_pi(&self) -> DisPi

Disable periodic interrupt in the functional interrupt

pub const fn set_dis_pi(&mut self, val: DisPi)

Disable periodic interrupt in the functional interrupt

pub const fn pi_en(&self) -> bool

HP Periodic Interrupt Enable The periodic interrupt can be generated only if the HP Real Time Counter is enabled

pub const fn set_pi_en(&mut self, val: bool)

HP Periodic Interrupt Enable The periodic interrupt can be generated only if the HP Real Time Counter is enabled

pub const fn pi_freq(&self) -> PiFreq

Periodic Interrupt Frequency Defines frequency of the periodic interrupt

pub const fn set_pi_freq(&mut self, val: PiFreq)

Periodic Interrupt Frequency Defines frequency of the periodic interrupt

pub const fn hpcalb_en(&self) -> bool

HP Real Time Counter Calibration Enabled Indicates that the time calibration mechanism is enabled.

pub const fn set_hpcalb_en(&mut self, val: bool)

HP Real Time Counter Calibration Enabled Indicates that the time calibration mechanism is enabled.

pub const fn hpcalb_val(&self) -> HpcalbVal

HP Calibration Value Defines signed calibration value for the HP Real Time Counter

pub const fn set_hpcalb_val(&mut self, val: HpcalbVal)

HP Calibration Value Defines signed calibration value for the HP Real Time Counter

pub const fn hp_ts(&self) -> HpTs

HP Time Synchronize

pub const fn set_hp_ts(&mut self, val: HpTs)

HP Time Synchronize

pub const fn btn_config(&self) -> u8

Button Configuration

pub const fn set_btn_config(&mut self, val: u8)

Button Configuration

pub const fn btn_mask(&self) -> bool

Button interrupt mask

pub const fn set_btn_mask(&mut self, val: bool)

Button interrupt mask