#[repr(transparent)]pub struct Hphacivr(pub u32);Expand description
SNVS_HP High Assurance Counter IV Register
Tuple Fields
0: u32Implementations
Sourceimpl Hphacivr
impl Hphacivr
Sourcepub const fn hac_counter_iv(&self) -> u32
pub const fn hac_counter_iv(&self) -> u32
High Assurance Counter Initial Value This register is used to set the starting count value to the high assurance counter
Sourcepub const fn set_hac_counter_iv(&mut self, val: u32)
pub const fn set_hac_counter_iv(&mut self, val: u32)
High Assurance Counter Initial Value This register is used to set the starting count value to the high assurance counter