nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Hphacr

Struct Hphacr 

#[repr(transparent)]
pub struct Hphacr(pub u32);
SNVS_HP High Assurance Counter Register

Tuple Fields

0: u32

Implementations

Source

impl Hphacr

pub const fn hac_counter(&self) -> u32

High Assurance Counter When the HAC_EN bit is set and the SSM is in the soft fail state, this counter starts to count down with the system clock

pub const fn set_hac_counter(&mut self, val: u32)

High Assurance Counter When the HAC_EN bit is set and the SSM is in the soft fail state, this counter starts to count down with the system clock