nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Hpsvcr

Struct Hpsvcr 

#[repr(transparent)]
pub struct Hpsvcr(pub u32);
SNVS_HP Security Violation Control Register

Tuple Fields

0: u32

Implementations

Source

impl Hpsvcr

pub const fn sv0_cfg(&self) -> Sv0Cfg

Security Violation 0 Security Violation Configuration This field configures the Security Violation 0 Security Violation Input

pub const fn set_sv0_cfg(&mut self, val: Sv0Cfg)

Security Violation 0 Security Violation Configuration This field configures the Security Violation 0 Security Violation Input

pub const fn sv1_cfg(&self) -> Sv1Cfg

Security Violation 1 Security Violation Configuration This field configures the Security Violation 1 Security Violation Input

pub const fn set_sv1_cfg(&mut self, val: Sv1Cfg)

Security Violation 1 Security Violation Configuration This field configures the Security Violation 1 Security Violation Input

pub const fn sv2_cfg(&self) -> Sv2Cfg

Security Violation 2 Security Violation Configuration This field configures the Security Violation 2 Security Violation Input

pub const fn set_sv2_cfg(&mut self, val: Sv2Cfg)

Security Violation 2 Security Violation Configuration This field configures the Security Violation 2 Security Violation Input

pub const fn sv3_cfg(&self) -> Sv3Cfg

Security Violation 3 Security Violation Configuration This field configures the Security Violation 3 Security Violation Input

pub const fn set_sv3_cfg(&mut self, val: Sv3Cfg)

Security Violation 3 Security Violation Configuration This field configures the Security Violation 3 Security Violation Input

pub const fn sv4_cfg(&self) -> Sv4Cfg

Security Violation 4 Security Violation Configuration This field configures the Security Violation 4 Security Violation Input

pub const fn set_sv4_cfg(&mut self, val: Sv4Cfg)

Security Violation 4 Security Violation Configuration This field configures the Security Violation 4 Security Violation Input

pub const fn sv5_cfg(&self) -> Sv5Cfg

Security Violation 5 Security Violation Configuration This field configures the Security Violation 5 Security Violation Input

pub const fn set_sv5_cfg(&mut self, val: Sv5Cfg)

Security Violation 5 Security Violation Configuration This field configures the Security Violation 5 Security Violation Input

pub const fn lpsv_cfg(&self) -> LpsvCfg

LP Security Violation Configuration This field configures the LP security violation source.

pub const fn set_lpsv_cfg(&mut self, val: LpsvCfg)

LP Security Violation Configuration This field configures the LP security violation source.