#[repr(transparent)]pub struct Lpcr(pub u32);Expand description
SNVS_LP Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Lpcr
impl Lpcr
Sourcepub const fn srtc_env(&self) -> bool
pub const fn srtc_env(&self) -> bool
Secure Real Time Counter Enabled and Valid When set, the SRTC becomes operational
Sourcepub const fn set_srtc_env(&mut self, val: bool)
pub const fn set_srtc_env(&mut self, val: bool)
Secure Real Time Counter Enabled and Valid When set, the SRTC becomes operational
Sourcepub const fn lpta_en(&self) -> bool
pub const fn lpta_en(&self) -> bool
LP Time Alarm Enable When set, the SNVS functional interrupt is asserted if the LP Time Alarm Register is equal to the 32 MSBs of the secure real time counter
Sourcepub const fn set_lpta_en(&mut self, val: bool)
pub const fn set_lpta_en(&mut self, val: bool)
LP Time Alarm Enable When set, the SNVS functional interrupt is asserted if the LP Time Alarm Register is equal to the 32 MSBs of the secure real time counter
Sourcepub const fn mc_env(&self) -> bool
pub const fn mc_env(&self) -> bool
Monotonic Counter Enabled and Valid When set, the MC can be incremented (by write transaction to the LPSMCMR or LPSMCLR)
Sourcepub const fn set_mc_env(&mut self, val: bool)
pub const fn set_mc_env(&mut self, val: bool)
Monotonic Counter Enabled and Valid When set, the MC can be incremented (by write transaction to the LPSMCMR or LPSMCLR)
Sourcepub const fn lpwui_en(&self) -> bool
pub const fn lpwui_en(&self) -> bool
LP Wake-Up Interrupt Enable This interrupt line should be connected to the external pin and is intended to inform the external chip about an SNVS_LP event (MC rollover, SRTC rollover, or time alarm )
Sourcepub const fn set_lpwui_en(&mut self, val: bool)
pub const fn set_lpwui_en(&mut self, val: bool)
LP Wake-Up Interrupt Enable This interrupt line should be connected to the external pin and is intended to inform the external chip about an SNVS_LP event (MC rollover, SRTC rollover, or time alarm )
Sourcepub const fn srtc_inv_en(&self) -> SrtcInvEn
pub const fn srtc_inv_en(&self) -> SrtcInvEn
If this bit is 1, in the case of a security violation the SRTC stops counting and the SRTC is invalidated (SRTC_ENV bit is cleared)
Sourcepub const fn set_srtc_inv_en(&mut self, val: SrtcInvEn)
pub const fn set_srtc_inv_en(&mut self, val: SrtcInvEn)
If this bit is 1, in the case of a security violation the SRTC stops counting and the SRTC is invalidated (SRTC_ENV bit is cleared)
Sourcepub const fn dp_en(&self) -> DpEn
pub const fn dp_en(&self) -> DpEn
Dumb PMIC Enabled When set, software can control the system power
Sourcepub const fn set_dp_en(&mut self, val: DpEn)
pub const fn set_dp_en(&mut self, val: DpEn)
Dumb PMIC Enabled When set, software can control the system power
Sourcepub const fn top(&self) -> Top
pub const fn top(&self) -> Top
Turn off System Power Asserting this bit causes a signal to be sent to the Power Management IC to turn off the system power
Sourcepub const fn set_top(&mut self, val: Top)
pub const fn set_top(&mut self, val: Top)
Turn off System Power Asserting this bit causes a signal to be sent to the Power Management IC to turn off the system power
Sourcepub const fn lvd_en(&self) -> bool
pub const fn lvd_en(&self) -> bool
Digital Low-Voltage Event Enable By default the detection of a low-voltage event does not cause the pmic_en_b signal to be asserted
Sourcepub const fn set_lvd_en(&mut self, val: bool)
pub const fn set_lvd_en(&mut self, val: bool)
Digital Low-Voltage Event Enable By default the detection of a low-voltage event does not cause the pmic_en_b signal to be asserted
Sourcepub const fn lpcalb_en(&self) -> bool
pub const fn lpcalb_en(&self) -> bool
LP Calibration Enable When set, enables the SRTC calibration mechanism
Sourcepub const fn set_lpcalb_en(&mut self, val: bool)
pub const fn set_lpcalb_en(&mut self, val: bool)
LP Calibration Enable When set, enables the SRTC calibration mechanism
Sourcepub const fn lpcalb_val(&self) -> LpcalbVal
pub const fn lpcalb_val(&self) -> LpcalbVal
LP Calibration Value Defines signed calibration value for SRTC
Sourcepub const fn set_lpcalb_val(&mut self, val: LpcalbVal)
pub const fn set_lpcalb_val(&mut self, val: LpcalbVal)
LP Calibration Value Defines signed calibration value for SRTC
Sourcepub const fn btn_press_time(&self) -> u8
pub const fn btn_press_time(&self) -> u8
This field configures the button press time out values for the PMIC Logic
Sourcepub const fn set_btn_press_time(&mut self, val: u8)
pub const fn set_btn_press_time(&mut self, val: u8)
This field configures the button press time out values for the PMIC Logic
Sourcepub const fn debounce(&self) -> u8
pub const fn debounce(&self) -> u8
This field configures the amount of debounce time for the BTN input signal
Sourcepub const fn set_debounce(&mut self, val: u8)
pub const fn set_debounce(&mut self, val: u8)
This field configures the amount of debounce time for the BTN input signal
Sourcepub const fn on_time(&self) -> u8
pub const fn on_time(&self) -> u8
The ON_TIME field is used to configure the period of time after BTN is asserted before pmic_en_b is asserted to turn on the SoC power
Sourcepub const fn set_on_time(&mut self, val: u8)
pub const fn set_on_time(&mut self, val: u8)
The ON_TIME field is used to configure the period of time after BTN is asserted before pmic_en_b is asserted to turn on the SoC power
Sourcepub const fn pk_en(&self) -> bool
pub const fn pk_en(&self) -> bool
PMIC On Request Enable The value written to PK_EN will be asserted on output signal snvs_lp_pk_en
Sourcepub const fn set_pk_en(&mut self, val: bool)
pub const fn set_pk_en(&mut self, val: bool)
PMIC On Request Enable The value written to PK_EN will be asserted on output signal snvs_lp_pk_en
Sourcepub const fn pk_override(&self) -> bool
pub const fn pk_override(&self) -> bool
PMIC On Request Override The value written to PK_OVERRIDE will be asserted on output signal snvs_lp_pk_override
Sourcepub const fn set_pk_override(&mut self, val: bool)
pub const fn set_pk_override(&mut self, val: bool)
PMIC On Request Override The value written to PK_OVERRIDE will be asserted on output signal snvs_lp_pk_override
Sourcepub const fn set_gpr_z_dis(&mut self, val: bool)
pub const fn set_gpr_z_dis(&mut self, val: bool)
General Purpose Registers Zeroization Disable