#[repr(transparent)]pub struct Lplr(pub u32);Expand description
SNVS_LP Lock Register
Tuple Fields
0: u32Implementations
Sourceimpl Lplr
impl Lplr
Sourcepub const fn zmk_whl(&self) -> ZmkWhl
pub const fn zmk_whl(&self) -> ZmkWhl
Zeroizable Master Key Write Hard Lock When set, prevents any writes (software and hardware) to the ZMK registers and ZMK_HWP, ZMK_VAL, and ZMK_ECC_EN fields of the LPMKCR
Sourcepub const fn set_zmk_whl(&mut self, val: ZmkWhl)
pub const fn set_zmk_whl(&mut self, val: ZmkWhl)
Zeroizable Master Key Write Hard Lock When set, prevents any writes (software and hardware) to the ZMK registers and ZMK_HWP, ZMK_VAL, and ZMK_ECC_EN fields of the LPMKCR
Sourcepub const fn zmk_rhl(&self) -> ZmkRhl
pub const fn zmk_rhl(&self) -> ZmkRhl
Zeroizable Master Key Read Hard Lock When set, prevents any software reads to the ZMK registers and ZMK_ECC_VALUE field of the LPMKCR
Sourcepub const fn set_zmk_rhl(&mut self, val: ZmkRhl)
pub const fn set_zmk_rhl(&mut self, val: ZmkRhl)
Zeroizable Master Key Read Hard Lock When set, prevents any software reads to the ZMK registers and ZMK_ECC_VALUE field of the LPMKCR
Sourcepub const fn srtc_hl(&self) -> SrtcHl
pub const fn srtc_hl(&self) -> SrtcHl
Secure Real Time Counter Hard Lock When set, prevents any writes to the SRTC registers, SRTC_ENV, and SRTC_INV_EN bits
Sourcepub const fn set_srtc_hl(&mut self, val: SrtcHl)
pub const fn set_srtc_hl(&mut self, val: SrtcHl)
Secure Real Time Counter Hard Lock When set, prevents any writes to the SRTC registers, SRTC_ENV, and SRTC_INV_EN bits
Sourcepub const fn lpcalb_hl(&self) -> LpcalbHl
pub const fn lpcalb_hl(&self) -> LpcalbHl
LP Calibration Hard Lock When set, prevents any writes to the LP Calibration Value (LPCALB_VAL) and LP Calibration Enable (LPCALB_EN)
Sourcepub const fn set_lpcalb_hl(&mut self, val: LpcalbHl)
pub const fn set_lpcalb_hl(&mut self, val: LpcalbHl)
LP Calibration Hard Lock When set, prevents any writes to the LP Calibration Value (LPCALB_VAL) and LP Calibration Enable (LPCALB_EN)
Sourcepub const fn mc_hl(&self) -> McHl
pub const fn mc_hl(&self) -> McHl
Monotonic Counter Hard Lock When set, prevents any writes (increments) to the MC Registers and MC_ENV bit
Sourcepub const fn set_mc_hl(&mut self, val: McHl)
pub const fn set_mc_hl(&mut self, val: McHl)
Monotonic Counter Hard Lock When set, prevents any writes (increments) to the MC Registers and MC_ENV bit
Sourcepub const fn gpr_hl(&self) -> GprHl
pub const fn gpr_hl(&self) -> GprHl
General Purpose Register Hard Lock When set, prevents any writes to the GPR
Sourcepub const fn set_gpr_hl(&mut self, val: GprHl)
pub const fn set_gpr_hl(&mut self, val: GprHl)
General Purpose Register Hard Lock When set, prevents any writes to the GPR
Sourcepub const fn lpsvcr_hl(&self) -> LpsvcrHl
pub const fn lpsvcr_hl(&self) -> LpsvcrHl
LP Security Violation Control Register Hard Lock When set, prevents any writes to the LPSVCR
Sourcepub const fn set_lpsvcr_hl(&mut self, val: LpsvcrHl)
pub const fn set_lpsvcr_hl(&mut self, val: LpsvcrHl)
LP Security Violation Control Register Hard Lock When set, prevents any writes to the LPSVCR
Sourcepub const fn lpsecr_hl(&self) -> LpsecrHl
pub const fn lpsecr_hl(&self) -> LpsecrHl
LP Security Events Configuration Register Hard Lock When set, prevents any writes to the LPSECR
Sourcepub const fn set_lpsecr_hl(&mut self, val: LpsecrHl)
pub const fn set_lpsecr_hl(&mut self, val: LpsecrHl)
LP Security Events Configuration Register Hard Lock When set, prevents any writes to the LPSECR
Sourcepub const fn mks_hl(&self) -> MksHl
pub const fn mks_hl(&self) -> MksHl
Master Key Select Hard Lock When set, prevents any writes to the MASTER_KEY_SEL field of the LP Master Key Control Register
Sourcepub const fn set_mks_hl(&mut self, val: MksHl)
pub const fn set_mks_hl(&mut self, val: MksHl)
Master Key Select Hard Lock When set, prevents any writes to the MASTER_KEY_SEL field of the LP Master Key Control Register