nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Lpsrtclr

Struct Lpsrtclr 

#[repr(transparent)]
pub struct Lpsrtclr(pub u32);
SNVS_LP Secure Real Time Counter LSB Register

Tuple Fields

0: u32

Implementations

Source

impl Lpsrtclr

pub const fn srtc(&self) -> u32

LP Secure Real Time Counter least-significant 32 bits This register can be programmed only when SRTC is not active and not locked, meaning the SRTC_ENV, SRTC_SL, and SRTC_HL bits are not set

pub const fn set_srtc(&mut self, val: u32)

LP Secure Real Time Counter least-significant 32 bits This register can be programmed only when SRTC is not active and not locked, meaning the SRTC_ENV, SRTC_SL, and SRTC_HL bits are not set