nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Lptar

Struct Lptar 

#[repr(transparent)]
pub struct Lptar(pub u32);
SNVS_LP Time Alarm Register

Tuple Fields

0: u32

Implementations

Source

impl Lptar

pub const fn lpta(&self) -> u32

LP Time Alarm This register can be programmed only when the LP time alarm is disabled (LPTA_EN bit is not set)

pub const fn set_lpta(&mut self, val: u32)

LP Time Alarm This register can be programmed only when the LP time alarm is disabled (LPTA_EN bit is not set)